@@ -174,7 +174,9 @@
  *
  * (not official API)
  */
-#ifdef GST_DISABLE_PRINTF_EXTENSION
+/* If GLib is not using the system printf, we can't use the registered
+ * extensions because the GLib-internal printf won't know how to parse them */
+#if defined(GST_DISABLE_PRINTF_EXTENSION) || !defined(GLIB_USING_SYSTEM_PRINTF)
   #undef GST_PTR_FORMAT
   #define GST_PTR_FORMAT "p"
   #undef GST_SEGMENT_FORMAT
@@ -194,7 +196,9 @@
 /* FIXME: move include to where we need it */
 /*#if (! (defined(GST_DISABLE_LOADSAVE) && defined(GST_DISABLE_REGISTRY)) )*/
 #ifndef GST_DISABLE_XML
+#ifndef GST_DISABLE_DEPRECATED
 # include <libxml/parser.h>
+#endif
 #else
   /* FIXME: 0.11 (replace by GST_DISABLE_XML) */
 # define GST_DISABLE_LOADSAVE_REGISTRY
